| Title: | Download and Processing of Automatic Weather Stations (AWS) Data of INMET-Brazil |
|---|---|
| Description: | A collection of functions for downloading and processing automatic weather station (AWS) data from INMET (Brazil’s National Institute of Meteorology), designed to support the estimation of reference evapotranspiration (ETo). The package facilitates streamlined access to meteorological data and aims to simplify analyses in agricultural and environmental contexts. |
| Authors: | Roberto Filgueiras [aut, cre] (ORCID: <https://orcid.org/0000-0002-0186-8907>), Luan P. Venancio [aut] (ORCID: <https://orcid.org/0000-0002-5544-8588>), Catariny C. Aleman [aut] (ORCID: <https://orcid.org/0000-0002-3894-3077>), Fernando F. da Cunha [aut] (ORCID: <https://orcid.org/0000-0002-1671-1021>), Arthur T. Calegario [ctb] (ORCID: <https://orcid.org/0000-0002-1921-5234>) |
| Maintainer: | Roberto Filgueiras <[email protected]> |
| License: | GPL-3 |
| Version: | 0.4.0 |
| Built: | 2026-06-03 11:23:51 UTC |
| Source: | https://github.com/filgueirasr/brazilmet |
Correction for Thorntwaite - Potential evapotranspiration
correction_etp_thornwaite(etp, date, lat)correction_etp_thornwaite(etp, date, lat)
etp |
A column of a dataframe containing Thorntwaite potential evapotranspiration (ETp) data without adjustments for sunlight hours and the number of days in the month.". |
date |
A column of dataframe with date (i.e: 2025-01-02). |
lat |
A column of dataframe with latitude in degrees. |
Returns a vector object with the Thorntwaite ETp corrected for sunlight hours and the number of days in the month.
Roberto Filgueiras.
## Not run: etp_cor <- correction_etp_thornwaite(etp, date, lat) ## End(Not run)## Not run: etp_cor <- correction_etp_thornwaite(etp, date, lat) ## End(Not run)
This function will calculate the reference evapotranspiration (ETo) based on FAO-56 (Allen et al., 1998) with the automatic weather stations (AWS) data, downloaded and processed in function *daily_download_AWS_INMET*.
daily_eto_FAO56(lat, tmin, tmax, tmean, Rs, u2, Patm, RH_max, RH_min, z, date)daily_eto_FAO56(lat, tmin, tmax, tmean, Rs, u2, Patm, RH_max, RH_min, z, date)
lat |
A numeric value of the Latitude of the AWS (decimal degrees). |
tmin |
A dataframe with Minimum daily air temperature (Celsius). |
tmax |
A dataframe with Maximum daily air temperature (Celsius). |
tmean |
A dataframe with Mean daily air temperature (Celsius). |
Rs |
A dataframe with mean daily solar radiation (MJ m-2 day-1). |
u2 |
A dataframe with Wind speed at two meters high (m s-2). |
Patm |
A dataframe with atmospheric Pressure (mB). |
RH_max |
A dataframe with Maximum relative humidity (percentage). |
RH_min |
A dataframe with Minimum relative humidity (percentage). |
z |
A numeric value of the altitude of AWS (m). |
date |
A data.frame with the date information (YYYY-MM-DD). |
Returns a data.frame with the AWS data requested
Roberto Filgueiras, Luan P. Venancio, Catariny C. Aleman and Fernando F. da Cunha
## Not run: eto <- daily_eto_FAO56(lat, tmin, tmax, tmean, Rs, u2, Patm, RH_max, RH_min, z, date) ## End(Not run)## Not run: eto <- daily_eto_FAO56(lat, tmin, tmax, tmean, Rs, u2, Patm, RH_max, RH_min, z, date) ## End(Not run)
Function to calculate the reference evapotranspitation for irrigation design.
design_eto(eto_daily_data, percentile = 0.8, grouping = NULL)design_eto(eto_daily_data, percentile = 0.8, grouping = NULL)
eto_daily_data |
A data frame containing daily reference evapotranspiration values (mm day-1) named as "ETo", and other column with dates named "date". To estimate the design reference evapotranspiration, it is recommended to use more than 10 years of historical data. |
percentile |
The relative position of a value within the data distribution. The recomendation to desing irrigating is greater than 80 percent (0.8). For instance: The 90th (0.90) percentile of reference evapotranspiration (ETo) represents a value that is surpassed in only 10 percent of the observed period. |
grouping |
specifies the column used to group the data, typically by station. Use this parameter to calculate the design ETo separately for each station, based on the corresponding station code. |
Returns a numeric object with the desing ETo for the respective data and percentile.
Roberto Filgueiras
## Not run: design_eto_value <- design_eto(eto, percentile) ## End(Not run)## Not run: design_eto_value <- design_eto(eto, percentile) ## End(Not run)
This function will download the hourly AWS data of INMET and it will aggregate the data in a daily time scale, based on the period of time selected (start_date and end_date).
download_AWS_INMET_daily(stations, start_date, end_date)download_AWS_INMET_daily(stations, start_date, end_date)
stations |
The stations code (ID - WMO code) for download. To see the station ID, please see the function *see_stations_info*. |
start_date |
Date that start the investigation, should be in the following format (1958-01-01 /Year-Month-Day) |
end_date |
Date that end the investigation, should be in the following format (2017-12-31 /Year-Month-Day) |
Returns a data.frame with the AWS data requested
Roberto Filgueiras, Luan P. Venancio, Catariny C. Aleman and Fernando F. da Cunha
## Not run: df <- download_AWS_INMET_daily( stations = c("A001", "A042"), start_date = "2016-01-01", end_date = "2018-12-31" ) ## End(Not run)## Not run: df <- download_AWS_INMET_daily( stations = c("A001", "A042"), start_date = "2016-01-01", end_date = "2018-12-31" ) ## End(Not run)
This function will download the climatological normals from CWS stations available in Inmet site.
download_climate_normals(variable, range_time)download_climate_normals(variable, range_time)
variable |
The variables available to download. The available variables are: rainfall_norm, t2m_norm, rh_norm, ws_norm and etp_norm. |
range_time |
The range of time which the climatological normals were computed. The available range of time is: "1991-2020". |
Returns a data.frame with climatological normal required.
Roberto Filgueiras
## Not run: df <- download_climate_normals( variable = "rainfall_norm", range_time = "1991-2020" ) ## End(Not run)## Not run: df <- download_climate_normals( variable = "rainfall_norm", range_time = "1991-2020" ) ## End(Not run)
Actual vapour pressure (ea) derived from dewpoint temperature
ea_dew_calculation(tdew)ea_dew_calculation(tdew)
tdew |
A dataframe with dewpoint temperature (Celsius). |
Returns a data.frame object with the ea from dewpoint data.
Roberto Filgueiras, Luan P. Venancio, Catariny C. Aleman and Fernando F. da Cunha.
## Not run: ea <-ea_dew_calculation(tdew) ## End(Not run)## Not run: ea <-ea_dew_calculation(tdew) ## End(Not run)
Actual vapour pressure (ea) derived from relative humidity data
ea_rh_calculation(tmin, tmax, rh_min, rh_mean, rh_max)ea_rh_calculation(tmin, tmax, rh_min, rh_mean, rh_max)
tmin |
A dataframe with minimum daily air temperature (Celsius) |
tmax |
A dataframe with maximum daily air temperature (Celsius) |
rh_min |
A dataframe with minimum daily relative air humidity (percentage). |
rh_mean |
A dataframe with mean daily relative air humidity (percentage). |
rh_max |
A dataframe with maximum daily relative air humidity (percentage). |
Returns a data.frame object with the with ea from relative humidity data.
Roberto Filgueiras, Luan P. Venancio, Catariny C. Aleman and Fernando F. da Cunha
## Not run: ea <- ea_rh_calculation(tmin, tmax, rh_min, rh_mean, rh_max) ## End(Not run)## Not run: ea <- ea_rh_calculation(tmin, tmax, rh_min, rh_mean, rh_max) ## End(Not run)
Mean saturation vapour pressure (es)
es_calculation(tmin, tmax)es_calculation(tmin, tmax)
tmin |
A dataframe with Minimum daily air temperature (Celsius). |
tmax |
A dataframe with Maximum daily air temperature (Celsius). |
Returns a data.frame object with the es data.
Roberto Filgueiras, Luan P. Venancio, Catariny C. Aleman and Fernando F. da Cunha.
## Not run: es <-es_calculation(tmin, tmax) ## End(Not run)## Not run: es <-es_calculation(tmin, tmax) ## End(Not run)
Vapour pressure deficit (es - ea)
es_ea_calculation(tmin, tmax, tdew, rh_min, rh_mean, rh_max, ea_method)es_ea_calculation(tmin, tmax, tdew, rh_min, rh_mean, rh_max, ea_method)
tmin |
A dataframe with minimum daily air temperature (Celsius). |
tmax |
A dataframe with maximum daily air temperature (Celsius). |
tdew |
A dataframe with dewpoint temperature (Celsius). |
rh_min |
A dataframe with minimum daily relative air humidity (percentage). |
rh_mean |
A dataframe with mean daily relative air humidity (percentage). |
rh_max |
A dataframe with maximum daily relative air humidity (percentage). |
ea_method |
The methodology to calculate the actual vapour pressure. Assume the "rh" (default) for relative humidity procedure and "dew" for dewpoint temperature procedure. |
Returns a data.frame object with the ea from relative humidity data.
Roberto Filgueiras, Luan P. Venancio, Catariny C. Aleman and Fernando F. da Cunha
## Not run: ea <- es_ea_calculation(tmin, tmax, tdew, rh_min, rh_mean, rh_max, ea_method) ## End(Not run)## Not run: ea <- es_ea_calculation(tmin, tmax, tdew, rh_min, rh_mean, rh_max, ea_method) ## End(Not run)
Hargreaves - Samani ETo
eto_hs(tmin, tmean, tmax, ra)eto_hs(tmin, tmean, tmax, ra)
tmin |
A numeric object with Maximum daily air temperature (Celsius) |
tmean |
A numeric object with Mean daily air temperature (Celsius) |
tmax |
A numeric object with Maximum daily air temperature (Celsius) |
ra |
A numeric object of extraterrestrial radiation (MJ m-2 day-1) |
Returns a numeric object with the ETo HS data
Roberto Filgueiras, Luan P. Venancio, Catariny C. Aleman and Fernando F. da Cunha
## Not run: eto_hs <- eto_hs(tmin, tmean, tmax, ra) ## End(Not run)## Not run: eto_hs <- eto_hs(tmin, tmean, tmax, ra) ## End(Not run)
Thorntwaite - Potential evapotranspiration
etp_thorntwaite(tmean)etp_thorntwaite(tmean)
tmean |
A dataframe with Mean monthly air temperature (Celsius) |
Returns a data.frame object with the Thorntwaite ETp data
Roberto Filgueiras.
## Not run: etp <- etp_thorntwaite(tmean) ## End(Not run)## Not run: etp <- etp_thorntwaite(tmean) ## End(Not run)
Extract maximum reference evapotranspiration (max ETo) values for one or more locations of interest, using data from the dataset provided by Dias (2018).
get_max_eto_at_location(img, lat, long)get_max_eto_at_location(img, lat, long)
img |
SpatRaster with the maximum reference evapotranspiration (ETo) grid downloaded from max_eto_grid_download. |
lat |
Numeric. Latitude of the location in decimal degrees. |
long |
Numeric. Longitude of the location in decimal degrees. |
A 'data.frame' object containing the maximum reference evapotranspiration (ETo) values per pair of coordinates.
Roberto Filgueiras.
## Not run: # Visualize Brazilian states (optional) max_eto_df <- get_max_reference_eto_by_location(img, long = c(-51.95, -43.23), lat = c(-23.52, -21.34)) ## End(Not run)## Not run: # Visualize Brazilian states (optional) max_eto_df <- get_max_reference_eto_by_location(img, long = c(-51.95, -43.23), lat = c(-23.52, -21.34)) ## End(Not run)
This function will download the hourly AWS data of INMET for whatever station of interest, based on the period of time selected (start_date and end_date) and station code.
hourly_weather_station_download(stations, start_date, end_date)hourly_weather_station_download(stations, start_date, end_date)
stations |
The station code (ID - WMO code) for download. To see the station ID, please see the function *see_stations_info*. |
start_date |
Date that start the investigation, should be in the following format (1958-01-01 /Year-Month-Day) |
end_date |
Date that end the investigation, should be in the following format (2017-12-31 /Year-Month-Day) |
Returns a data.frame with the AWS data requested
Roberto Filgueiras
## Not run: df <- hourly_weather_station_download( stations = c("A001", "A042"), start_date = "2022-08-12", end_date = "2022-08-16") ## End(Not run)## Not run: df <- hourly_weather_station_download( stations = c("A001", "A042"), start_date = "2022-08-12", end_date = "2022-08-16") ## End(Not run)
Downloads maximum reference evapotranspiration (ETo) grids for Brazil, intended for irrigation design purposes. The dataset was developed by Dias (2018).
max_eto_grid_download(dir_out, product = "max_12_months")max_eto_grid_download(dir_out, product = "max_12_months")
dir_out |
Character. Directory where the downloaded raster file will be saved. |
product |
Character. Specifies which maximum ETo product to download. Available options include:
|
A 'SpatRaster' object containing the downloaded maximum reference evapotranspiration (ETo) grid.
Roberto Filgueiras.
Dias, S. H. B. (2018). *Evapotranspiração de referência para projeto de irrigação no Brasil utilizando o produto MOD16*. Dissertação (Mestrado) – Universidade Federal de Viçosa.
## Not run: # Visualize Brazilian states (optional) see_brazil_states() # Download maximum ETo grid (annual) img_max_eto <- max_eto_grid_download(dir_out = "data/", product = "max_12_months") ## End(Not run)## Not run: # Visualize Brazilian states (optional) see_brazil_states() # Download maximum ETo grid (annual) img_max_eto <- max_eto_grid_download(dir_out = "data/", product = "max_12_months") ## End(Not run)
Atmospheric pressure (Patm)
Patm(z)Patm(z)
z |
Elevation above sea level (m) |
Returns a data.frame object with the atmospheric pressure calculated.
Roberto Filgueiras, Luan P. Venancio, Catariny C. Aleman and Fernando F. da Cunha
## Not run: Patm <- Patm(z) ## End(Not run)## Not run: Patm <- Patm(z) ## End(Not run)
Psychrometric constant (kPa/Celsius) is calculated in this function.
psy_const(Patm)psy_const(Patm)
Patm |
Atmospheric pressure (kPa) |
A data.frame object with the psychrometric constant calculated.
Roberto Filgueiras, Luan P. Venancio, Catariny C. Aleman and Fernando F. da Cunha
## Not run: psy_df <- psy_const(Patm) ## End(Not run)## Not run: psy_df <- psy_const(Patm) ## End(Not run)
ra is expressed in MJ m-2 day-1
ra_calculation(latitude, date)ra_calculation(latitude, date)
latitude |
A dataframe with latitude in decimal degrees that you want to calculate the ra. |
date |
A dataframe with the dates that you want to calculate the ra. |
A data.frame with the extraterrestrial radiation for daily periods
Roberto Filgueiras, Luan P. Venancio, Catariny C. Aleman and Fernando F. da Cunha
## Not run: ra <- ra_calculation(latitude, date) ## End(Not run)## Not run: ra <- ra_calculation(latitude, date) ## End(Not run)
Function to convert the radiation data. The conversion name can be understand as follow:
conversion_1 = MJ m-2 day-1 to J cm-2 day-1;
conversion_2 = MJ m-2 day-1 to cal cm-2 day-1;
conversion_3 = MJ m-2 day-1 to W m-2;
conversion_4 = MJ m-2 day-1 to mm day-1;
conversion_5 = cal cm-2 day-1 to MJ m-2 day-1;
conversion_6 = cal cm-2 day-1 to J cm-2 day-1;
conversion_7 = cal cm-2 day-1 to W m-2;
conversion_8 = cal cm-2 day-1 to mm day-1;
conversion_9 = W m-2 to MJ m-2 day-1;
conversion_10 = W m-2 to J cm-2 day-1;
conversion_11 = W m-2 to cal cm-2 day-1;
conversion_12 = W m-2 to mm day-1;
conversion_13 = mm day-1 to MJ m-2 day-1;
conversion_14 = mm day-1 to J cm-2 day-1;
conversion_15 = mm day-1 to cal cm-2 day-1;
conversion_16 = mm day-1 to W m-2.
radiation_conversion(data_to_convert, conversion_name)radiation_conversion(data_to_convert, conversion_name)
data_to_convert |
A data.frame with radiation values to convert. |
conversion_name |
A character with the conversion_name summarize in the description of this function. |
A data.frame object wit the converted radiation.
Roberto Filgueiras, Luan P. Venancio, Catariny C. Aleman and Fernando F. da Cunha
## Not run: radiation_conversion_df <- radiation_conversion( data_to_convert = df$rad, conversion_name = "conversion_1" ) ## End(Not run)## Not run: radiation_conversion_df <- radiation_conversion( data_to_convert = df$rad, conversion_name = "conversion_1" ) ## End(Not run)
Relative humidity is calculated in this function based on minimum air temperature of the day and the air temperature of the moment.
rh_calculation(tmin, tmean)rh_calculation(tmin, tmean)
tmin |
A dataframe with minimum daily air temperature (Celsius) |
tmean |
A dataframe with mean air temperature (Celsius) that you want to calculate the relative humidity. |
A data.frame object with the relative humidity calculated
Roberto Filgueiras, Luan P. Venancio, Catariny C. Aleman and Fernando F. da Cunha
## Not run: rh <- rh_calculation(tmin, tmean) ## End(Not run)## Not run: rh <- rh_calculation(tmin, tmean) ## End(Not run)
The net radiation (MJ m-2 day-1) is the difference between the incoming net shortwave radiation (rns) and the outgoing net longwave radiation (rnl).
rn_calculation(rns, rnl)rn_calculation(rns, rnl)
rns |
The incomimg net shortwave radiation (MJ m-2 day-1). |
rnl |
The outgoing net longwave radiation (MJ m-2 day-1). |
A data.frame object with the net radiation data.
Roberto Filgueiras, Luan P. Venancio, Catariny C. Aleman and Fernando F. da Cunha
## Not run: rn <- rn_calculation(rns, rnl) ## End(Not run)## Not run: rn <- rn_calculation(rns, rnl) ## End(Not run)
Net outgoing longwave radiation is calculate with this function
rnl_calculation(tmin, tmax, ea, rs, rso)rnl_calculation(tmin, tmax, ea, rs, rso)
tmin |
A dataframe with Minimum daily air temperature (Celsius) |
tmax |
A dataframe with Maximum daily air temperature (Celsius) |
ea |
A dataframe with the actual vapour pressure (KPa). |
rs |
A dataframe with the incomimg solar radiation (MJ m-2 day-1). |
rso |
A dataframe with the clear-sky radiation (MJ m-2 day-1) |
A data.frame object with the net longwave radiation.
Roberto Filgueiras, Luan P. Venancio, Catariny C. Aleman and Fernando F. da Cunha
## Not run: rnl_df <- rnl_calculation(tmin, tmax, ea, rs, rso) ## End(Not run)## Not run: rnl_df <- rnl_calculation(tmin, tmax, ea, rs, rso) ## End(Not run)
The rns results form the balance between incoming and reflected solar radiation (MJ m-2 day-1).
rns_calculation(albedo, rs)rns_calculation(albedo, rs)
albedo |
Albedo or canopy reflectance coefficient. The 0.23 is the value used for hypothetical grass reference crop (dimensionless). |
rs |
The incoming solar radiation (MJ m-2 day-1). |
A data.frame object with the net solar or net shortwave radiation data.
Roberto Filgueiras, Luan P. Venancio, Catariny C. Aleman and Fernando F. da Cunha
## Not run: ra <- rns_calculation(albedo, rs) ## End(Not run)## Not run: ra <- rns_calculation(albedo, rs) ## End(Not run)
The solar radiation data is calculated based in a nearby weather station.
rs_nearby_calculation(rs_reg, ra_reg, ra)rs_nearby_calculation(rs_reg, ra_reg, ra)
rs_reg |
A dataframe with the solar radiation at the regional location (MJ m-2 day-1). |
ra_reg |
A dataframe with the extraterrestrial radiation at the regional location (MJ m-2 day-1). |
ra |
A dataframe with the extraterrestrial radiation for daily periods (ra). |
A data.frame object with the Solar radiation data based on a nearby weather station
Roberto Filgueiras, Luan P. Venancio, Catariny C. Aleman and Fernando F. da Cunha
## Not run: rs_nearby_df <- rs_nearby_calculation(rs_reg, ra_reg, ra) ## End(Not run)## Not run: rs_nearby_df <- rs_nearby_calculation(rs_reg, ra_reg, ra) ## End(Not run)
Clear-sky solar radiation is calculated in this function for near sea level or when calibrated values for as and bs are available.
rso_calculation_1(as, bs, ra)rso_calculation_1(as, bs, ra)
as |
A dataframe with latitude in decimal degrees that you want to calculate the ra. The values of as = 0.25 is recommended by Allen et al. (1998). |
bs |
A dataframe with the dates that you want to calculate the ra. The values of bs = 0.50 is recommended by Allen et al. (1998). |
ra |
Extraterrestrial radiation for daily periods (ra). |
A data.frame object with the clear-sky radiation data
Roberto Filgueiras, Luan P. Venancio, Catariny C. Aleman and Fernando F. da Cunha
## Not run: rso_df <- rso_calculation_1(as, bs, ra) ## End(Not run)## Not run: rso_df <- rso_calculation_1(as, bs, ra) ## End(Not run)
Clear-sky solar radiation is calculated in this function for near sea level or when calibrated values for as and bs are available.
rso_calculation_2(z, ra)rso_calculation_2(z, ra)
z |
Station elevation above sea level (m) |
ra |
Extraterrestrial radiation for daily periods (ra). |
A data.frame object with the clear-sky solar radiation
Roberto Filgueiras, Luan P. Venancio, Catariny C. Aleman and Fernando F. da Cunha
## Not run: rso_df <- rso_calculation_2(z, ra) ## End(Not run)## Not run: rso_df <- rso_calculation_2(z, ra) ## End(Not run)
Function to see the localization of the automatic weather station of INMET.
see_stations_info()see_stations_info()
A data.frame with informations of OMM code, latitude, longitude and altitude of all AWS stations available in INMET.
Roberto Filgueiras, Luan P. Venancio, Catariny C. Aleman and Fernando F. da Cunha
## Not run: see_stations_info() ## End(Not run)## Not run: see_stations_info() ## End(Not run)
Select automatic weather stations of INMET based on sf object.
selectAWSstations(aoi, as_sf = FALSE)selectAWSstations(aoi, as_sf = FALSE)
aoi |
sf object. Area of interest. |
as_sf |
logical. Inmet stations inventory result should be export as sf object. Default = FALSE. |
a vector or sf object with station located at area of interest (aoi)
## Not run: es = geobr::read_municipality(code_muni = "ES") esStations = selectStations(aoi = es, as_sf = F); es ## End(Not run)## Not run: es = geobr::read_municipality(code_muni = "ES") esStations = selectStations(aoi = es, as_sf = F); es ## End(Not run)
If global radiation is not measure at station, it can be estimated with this function.
sr_ang_calculation(latitude, date, n, as, bs)sr_ang_calculation(latitude, date, n, as, bs)
latitude |
A dataframe with latitude in decimal degrees that you want to calculate the ra. |
date |
A dataframe with the dates that you want to calculate the ra. |
n |
The actual duration of sunshine. This variable is recorded with Campbell-Stokes sunshine recorder. |
as |
A dataframe with latitude in decimal degrees that you want to calculate the ra. The values of as = 0.25 is recommended by Allen et al. (1998). |
bs |
A dataframe with the dates that you want to calculate the ra. The values of bs = 0.50 is recommended by Allen et al. (1998). |
A data.frame object with solar radiation data
Roberto Filgueiras, Luan P. Venancio, Catariny C. Aleman and Fernando F. da Cunha
## Not run: sr_ang <- sr_ang_calculation(latitude, date, n, as, bs) ## End(Not run)## Not run: sr_ang <- sr_ang_calculation(latitude, date, n, as, bs) ## End(Not run)
If global radiation is not measure at station, it can be estimated with this function.
sr_tair_calculation(latitude, date, tmax, tmin, location_krs)sr_tair_calculation(latitude, date, tmax, tmin, location_krs)
latitude |
A dataframe with latitude in decimal degrees that you want to calculate the ra. |
date |
A dataframe with the dates that you want to calculate the ra. |
tmax |
A dataframe with Maximum daily air temperature (Celsius) |
tmin |
A dataframe with Minimum daily air temperature (Celsius) |
location_krs |
Adjustment coefficient based in location. Please decide between "coastal or "interior". If coastal the krs will be 0.19, if interior the krs will be 0.16. |
A data.frame object with solar radiation data
Roberto Filgueiras, Luan P. Venancio, Catariny C. Aleman and Fernando F. da Cunha
## Not run: sr_tair <- sr_tair_calculation(latitude, date, tmax, tmin, location_krs) ## End(Not run)## Not run: sr_tair <- sr_tair_calculation(latitude, date, tmax, tmin, location_krs) ## End(Not run)
Wind speed at two meters high can be calculated with this function.
u2_calculation(uz, z)u2_calculation(uz, z)
uz |
measured wind speed at z meters above ground surface |
z |
height of measurement above ground surface. |
A data.frame with the wind speed at 2 meters high calculated.
Roberto Filgueiras, Luan P. Venancio, Catariny C. Aleman and Fernando F. da Cunha
## Not run: u2_df <- u2_calculation(uz, z) ## End(Not run)## Not run: u2_df <- u2_calculation(uz, z) ## End(Not run)